========================
AWS ParallelCluster Node
========================

|Build Status| |Version|

.. |Build Status| image:: https://travis-ci.org/aws/aws-parallelcluster-node.png?branch=develop
    :target: https://travis-ci.org/aws/aws-parallelcluster-node/
    :alt: Build Status
.. |Version| image:: https://badge.fury.io/py/aws-parallelcluster-node.png
    :target: https://badge.fury.io/py/aws-parallelcluster-node

This repo contains the aws-parallelcluster-node package installed on the Amazon EC2 instances launched
as part of AWS ParallelCluster.